@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::GEEKRUTH;
 use Modern::Perl;
-our $VERSION   = '2.0001';           # VERSION
+our $VERSION   = '2.0002';           # VERSION
 our $AUTHORITY = 'cpan:GEEKRUTH';    # AUTHORITY
 
 # ABSTRACT: Be like GeekRuthie when you build your dists
@@ -76,9 +76,6 @@ sub configure {
          Manifest
          ManifestSkip
          Git::GatherDir
-         /,
-      [ CopyFilesFromBuild => { copy => 'cpanfile' } ],
-      qw/
          PruneCruft
          ExecDir
          OurPkgVersion
@@ -148,7 +145,7 @@ sub configure {
                push_to => join q{ }, $upstream, $dev_branch, $release_branch
             }
          ],
-         qw/UploadToCPAN/,
+         qw/FakeRelease/,
          [ 'InstallRelease' => { install_command => 'cpanm .' } ],
       );
    }
@@ -192,7 +189,7 @@ Dist::Zilla::PluginBundle::GEEKRUTH - Be like GeekRuthie when you build your dis
 
 =head1 VERSION
 
-version 2.0001
+version 2.0002
 
 =head1 DESCRIPTION
 
@@ -225,8 +222,6 @@ her distributions. It's roughly equivalent to
    [ManifestSkip]
    [Git::GatherDir]
    [PruneCruft]
-   [CopyFilesFromBuild]
-   copy = cpanfile
    [ExecDir]
    [OurPkgVersion]
    [INI::Baked]
